#ifndef TOK_H
#define TOK_H
///////////////////////////////////////////////////////////////
//  tok.h     --  read words from ASCII file                 //
//  ver 1.1                                                  //
//  Language:     Visual C++, ver 6.0                        //
//  Platform:     Micron Dual Pentium Pro 200, Win NT 4.0    //
//  Application:  CSE784 Example                             //
//  Author:       Jim Fawcett, CST 2-187, Syracuse Univ.     //
//                (315) 443-3948, fawcett@ecs.syr.edu        //
///////////////////////////////////////////////////////////////
/*

    Module Operations
    =================
    This tok class provides two public functions, a constructor
    that defines an existing file stream to process and a function 
    which extracts words from that file stream.  A word is a seq-
    uence of characters delimited by whitespace.  Punctuator seq-
    uences are separated from alphanumberic characters; and certain 
    punctuator characters are collected as single character tokens, 
    e.g.:
    
        '{', '}', '(', ')', '[', ']', ';'

    The tokenizer is used in the following way:

      ifstream in(filename);
      token toker(in);
      string tok;
      while(getTok(tok)) {

          // do things with collected tokens

      }

*/
//
/////////////////////////////////////////////////////////////// 
//  build process                                            //
///////////////////////////////////////////////////////////////
//                                                           //
//  Required Files:                                          //
//    tok.h, tok.cpp                                         //
//                                                           //
//  Compile Command:                                         //
//    cl -GX -DTEST_TOK tok.cpp                              //
//                                                           //
///////////////////////////////////////////////////////////////
/*
    
      Maintenance History
      ===================
      ver 1.1, 30 Jan 1999
        - cosmetic modifications to these pages
      ver 1.0, 20 Sep 1998
        - first release
      
*/

/////////////////////////////////////////////////////////////// 
//  declarations                                             //
/////////////////////////////////////////////////////////////// 

#include <iostream>

using namespace std;

class token {

  public:
    token(istream &input);
    bool getTok(string &buffer);

  private:
    istream &in;
    enum charType { Char, NewLine, White, Punct };
    charType type(char ch);
    int delim(char ch);
    int isComment(const string &buffer);
    int isWhite(const string &buffer);
    int eatWhite(string &buffer);
    int eatComment(string &buffer);
    int isQuote(const string &buffer);
    int collectQuote(string &buffer);
};

#endif
